@@ -1,9 +1,8 @@
-/* Copyright (C) 2000-2012 Peter Selinger.
+/* Copyright (C) 2000-2018 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
 /* user interface for ccrypt: casual encryption and decryption for files */
-/* $Id: main.h 305 2012-10-11 12:41:22Z selinger $ */ 
 
 #ifndef __MAIN_H
 #define __MAIN_H
@@ -17,7 +16,7 @@
 
 /* structure to hold command-line */
 typedef struct {
-  char *name;        /* invocation name: "NAMECCRYPT", "NAMECAT", etc */
+  const char *name;  /* invocation name: "NAMECCRYPT", "NAMECAT", etc */
   int verbose;       /* -1=quiet, 0=normal, 1=verbose */
   int debug;    
   char *keyword;
@@ -25,7 +24,7 @@ typedef struct {
   int mode;          /* ENCRYPT, DECRYPT, KEYCHANGE, CAT, UNIXCRYPT */
   int filter;        /* running as a filter? */
   int tmpfiles;      /* use temporary files instead of overwriting? */
-  char *suffix;
+  const char *suffix;
   const char *prompt;
   const char *prompt2;
   int recursive;     /* 0=non-recursive, 1=directories, 2=dirs and symlinks */
